from ilexconf.console.application import Application


def main():  # pragma: no cover
    return Application().run()
